@@ -342,6 +342,9 @@ class Constraint(metaclass=ConstraintMeta):
             LOGGER.debug('%s: %s invalid rows out of %s.',
                          self.__class__.__name__, sum(~valid), len(valid))
 
+        if isinstance(valid, pd.Series):
+            return table_data[valid.values]
+
         return table_data[valid]
 
     @classmethod
